<?php

ob_start();

//==================================================================
// ⡼
//
define( 'CHARCOAL_RUNMODE', 'http' );

//==================================================================
// ١ǥ쥯ȥ
//
define( 'BASE_DIR', dirname(dirname(__FILE__)) );

//==================================================================
// ۡǥ쥯ȥ

define( 'CHARCOAL_HOME', BASE_DIR . '/charcoal' );

//==================================================================
// WEB_APPǥ쥯ȥ
//
define( 'WEBAPP_DIR', BASE_DIR . "/web_app" );

//==================================================================
// ץꥱ̾
//
define( 'APPLICATION', "00_top" );

//==================================================================
// charcoal.inc.phpɤ߹
//
include( CHARCOAL_HOME . '/charcoal.inc.php');

//==================================================================
// ե졼ư
//
Framework::run();

ob_end_flush();

